@@ -10,8 +10,7 @@ from zipfile import ZipExtFile
 import numpy as np
 import sklearn
 import srsly
-from instancelib.analysis.base import (BinaryModelMetrics,
-                                       MulticlassModelMetrics)
+from instancelib.analysis.base import BinaryModelMetrics, MulticlassModelMetrics
 from instancelib.environment.base import Environment
 from instancelib.instances.base import Instance, InstanceProvider
 from instancelib.labels.base import LabelProvider
@@ -27,7 +26,7 @@ def export_instancelib(obj) -> Dict[str, Any]:
                 'labels': export_instancelib(obj.labels),
                 'named_providers': export_instancelib(obj.named_providers)}
     elif isinstance(obj, Instance):
-        return {k: export_safe(v) for k, v in obj.__dict__.items()}
+        return {k: export_safe(v) for k, v in obj.__dict__.items() if k not in ['_vector']}
     elif isinstance(obj, LabelProvider):
         return {'labelset': export_safe(obj._labelset),
                 'labeldict': {k: export_safe(v) for k, v in obj._labeldict.items()}}
@@ -64,15 +63,15 @@ def export_dict(nested: dict) -> Iterator[Tuple]:
 
 def export_safe(obj):
     """Safely export to transform into JSON or YAML."""
-    if isinstance(obj, np.integer):
+    if isinstance(obj, (int, np.integer)):
         return int(obj)
-    elif isinstance(obj, (np.floating, float)):
+    elif isinstance(obj, (float, np.floating)):
         return float(obj)
     elif isinstance(obj, np.ndarray):
         return obj.tolist()
     elif 'pandas' in str(type(obj)).lower() and hasattr(obj, 'to_dict') and callable(obj.to_dict):
         return obj.to_dict()
-    elif isinstance(obj, np.str):
+    elif isinstance(obj, str):
         return str(obj)
     elif isinstance(obj, (frozenset, set)):
         return [export_safe(o) for o in list(obj)]
@@ -114,6 +113,8 @@ def recursive_to_dict(nested: Any,
     if hasattr(nested, '__qualname__') and hasattr(nested, '__annotations__'):
         yield '__name__', str(nested.__qualname__)
         nested = nested.__annotations__
+    elif hasattr(nested, 'to_config') and callable(nested.to_config):
+        nested = nested.to_config()
     elif hasattr(nested, '__dict__'):
         nested = nested.__dict__
     if not hasattr(nested, 'items'):
@@ -160,6 +161,14 @@ def package_available(package: str) -> bool:
 
 
 def extract_metrics(metrics: dict) -> Tuple[dict, list]:
+    """Extract metrics.
+
+    Args:
+        metrics (dict): Metrics.
+
+    Returns:
+        Tuple[dict, list]: Tuple containing extracted metrics and property names.
+    """
     # Get all unique property names
     properties = []
 
